.. AUTO-GENERATED FILE -- DO NOT EDIT!

core.error
==========

Module: :mod:`core.error`
-------------------------
Inheritance diagram for ``zmq.core.error``:

.. inheritance-diagram:: zmq.core.error 
   :parts: 3

.. automodule:: zmq.core.error

.. currentmodule:: zmq.core.error

Classes
-------

:class:`NotDone`
~~~~~~~~~~~~~~~~


.. autoclass:: NotDone
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:


:class:`ZMQBaseError`
~~~~~~~~~~~~~~~~~~~~~


.. autoclass:: ZMQBaseError
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:


:class:`ZMQBindError`
~~~~~~~~~~~~~~~~~~~~~


.. autoclass:: ZMQBindError
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:


:class:`ZMQError`
~~~~~~~~~~~~~~~~~


.. autoclass:: ZMQError
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:


Function
--------


.. autofunction:: zmq.core.error.strerror

